@@ -13,7 +13,7 @@ AnyMock = Union[umock.AsyncMock, umock.MagicMock, umock.PropertyMock]
 AsyncAndSyncMock = Union[umock.AsyncMock, umock.MagicMock]
 
 
-class Assert:  # pylint: disable=too-many-public-methods
+class Assert:
     """Assert allows creation of assertions for mocks.
 
     The created assertions are automatically validated at the end of a test.
@@ -26,7 +26,9 @@ class Assert:  # pylint: disable=too-many-public-methods
         parent: Mock,
         attr_mock: AnyMock,
         name: str,
+        *,
         kind: Literal["spy", "mock"] = "mock",
+        patch: Optional[umock._patch[Any]] = None,  # pylint: disable=unsubscriptable-object
         _internal: bool = False,
     ) -> None:
         if not _internal:
@@ -37,6 +39,7 @@ class Assert:  # pylint: disable=too-many-public-methods
         self.__attr_mock = attr_mock
         self.__name = name
         self.__assertions: List[Callable[..., None]] = []
+        self.__patch = patch
         self._kind = kind
 
     def get_mock(self) -> AnyMock:
@@ -101,6 +104,12 @@ class Assert:  # pylint: disable=too-many-public-methods
         Returns:
             Assert instance so that calls can be chained.
         """
+        if isinstance(self.__attr_mock, umock.NonCallableMagicMock) and self.__patch is not None:
+            # Support mocking module attributes/variables
+            self.__patch.stop()
+            self.__patch.new = value
+            self.__patch.start()
+            return self
         self.__attr_mock.return_value = value
         return self
 
@@ -1259,7 +1268,7 @@ class Mock:
         )
         self.__assertions: Dict[str, Assert] = {}
         self.__object_patches: List[
-            umock._patch[AsyncAndSyncMock]  # pylint: disable=unsubscriptable-object
+            umock._patch[Any]  # pylint: disable=unsubscriptable-object
         ] = []
         self.__patch_class: bool = patch_class
 
@@ -1324,7 +1333,7 @@ class Mock:
         parsed_name = self.__remove_name_mangling(name)
         original = getattr(self.__target, parsed_name)
         attr_mock = self.__get_patch_attr_mock(
-            self.__mock, parsed_name, create=True, force_property=False
+            self.__mock, parsed_name, create=True, force_property=False, force_async=False
         )
         parameters = tuple(inspect.signature(original).parameters.keys())
         is_class_method = self.__get_method_type(parsed_name, classmethod)
@@ -1382,7 +1391,14 @@ class Mock:
                         return isinstance(method, method_type)
             return False
 
-    def mock(self, name: str, *, create: bool = False, force_property: bool = False) -> Assert:
+    def mock(
+        self,
+        name: str,
+        *,
+        create: bool = False,
+        force_property: bool = False,
+        force_async: bool = False,
+    ) -> Assert:
         """Mock an attribute.
 
         The given attribute is mocked and the mock catches all the calls to it.
@@ -1428,10 +1444,13 @@ class Mock:
                 want force the creation and ignore the error, set this to True.
                 This can be useful for testing dynamic attributes set during
                 runtime.
-            force_property: Force the mock to be a PropertyMock. This can be
+            force_property: Force the mock to be a `PropertyMock`. This can be
                 used to create properties on stubs or force the mock to be a
-                PropertyMock if the automatic attribute type detection from spec
-                does not work.
+                `PropertyMock` if the automatic detection from spec does not
+                work.
+            force_async: Force the mock to be a `AsyncMock`. This can be
+                used to create async methods on stubs or force the mock to be a
+                `AsyncMock` if the automatic detection from spec does not work.
 
         Returns:
             Assert instance.
@@ -1453,16 +1472,29 @@ class Mock:
             raise ValueError("Attribute name cannot be empty.")
         if self.__target is None:
             assertion = self.__stub_attribute(
-                parsed_name, parts, create=create, force_property=force_property
+                parsed_name,
+                parts,
+                create=create,
+                force_property=force_property,
+                force_async=force_async,
             )
         elif self.__patch is not None:
             assertion = self.__patch_attribute(
-                parsed_name, parts, create=create, force_property=force_property
+                parsed_name,
+                parts,
+                create=create,
+                force_property=force_property,
+                force_async=force_async,
             )
         else:
             original = self.__get_original(parsed_name, create)
             assertion = self.__mock_attribute(
-                parsed_name, parts, original, create=create, force_property=force_property
+                parsed_name,
+                parts,
+                original,
+                create=create,
+                force_property=force_property,
+                force_async=force_async,
             )
         assertion.return_value(None)
         self.__assertions[name] = assertion
@@ -1488,11 +1520,13 @@ class Mock:
             raise
 
     def __stub_attribute(
-        self, name: str, parts: List[str], *, create: bool, force_property: bool
+        self, name: str, parts: List[str], *, create: bool, force_property: bool, force_async: bool
     ) -> Assert:
         if name in list(set(dir(Mock)) - set(dir(type))):
             raise ValueError(f"Cannot replace Mock internal attribute {name}")
-        attr_mock = self.__get_stub_attr_mock(name, create=create, force_property=force_property)
+        attr_mock = self.__get_stub_attr_mock(
+            name, create=create, force_property=force_property, force_async=force_async
+        )
         assertion = Assert(self, attr_mock, name, _internal=True)
         if len(parts) > 0:
             # Support for chaining methods
@@ -1500,7 +1534,9 @@ class Mock:
             assertion = self.mock(".".join(parts))
         return assertion
 
-    def __get_stub_attr_mock(self, name: str, *, create: bool, force_property: bool) -> AnyMock:
+    def __get_stub_attr_mock(
+        self, name: str, *, create: bool, force_property: bool, force_async: bool
+    ) -> AnyMock:
         if self.__spec is not None:
             try:
                 original = getattr(self.__spec, name)
@@ -1508,7 +1544,7 @@ class Mock:
                 if create is True:
                     if force_property:
                         return self.__get_stub_property_mock(name)
-                    attr_mock = umock.MagicMock()
+                    attr_mock = umock.AsyncMock() if force_async else umock.MagicMock()
                     setattr(self, name, attr_mock)
                     return attr_mock
                 raise
@@ -1516,7 +1552,10 @@ class Mock:
                 return self.__get_stub_property_mock(name)
         if force_property:
             return self.__get_stub_property_mock(name)
-        attr_mock = getattr(self.__mock, name)
+        if force_async:
+            attr_mock = umock.AsyncMock()
+        else:
+            attr_mock = getattr(self.__mock, name)
         setattr(self, name, attr_mock)
         return attr_mock
 
@@ -1526,15 +1565,19 @@ class Mock:
         return attr_mock
 
     def __patch_attribute(
-        self, name: str, parts: List[str], *, create: bool, force_property: bool
+        self, name: str, parts: List[str], *, create: bool, force_property: bool, force_async: bool
     ) -> Assert:
         if not self.__patch_class and self.__patch and inspect.isclass(self.__patch.temp_original):
             attr_mock: AnyMock = self.__get_patch_attr_mock(
-                self.__mock(), name, create=create, force_property=force_property
+                self.__mock(),
+                name,
+                create=create,
+                force_property=force_property,
+                force_async=force_async,
             )
         else:
             attr_mock = self.__get_patch_attr_mock(
-                self.__mock, name, create=create, force_property=False
+                self.__mock, name, create=create, force_property=False, force_async=force_async
             )
         assertion = Assert(self, attr_mock, name, _internal=True)
         if len(parts) > 0:
@@ -1545,7 +1588,7 @@ class Mock:
         return assertion
 
     def __get_patch_attr_mock(
-        self, mock: AnyMock, name: str, *, create: bool, force_property: bool
+        self, mock: AnyMock, name: str, *, create: bool, force_property: bool, force_async: bool
     ) -> AnyMock:
         try:
             attr_mock = getattr(mock, name)
@@ -1553,7 +1596,7 @@ class Mock:
             if create is True:
                 if force_property:
                     return self.__get_patch_property_mock(mock, name)
-                attr_mock = umock.MagicMock()
+                attr_mock = umock.AsyncMock() if force_async else umock.MagicMock()
                 setattr(mock, name, attr_mock)
                 return attr_mock
             raise
@@ -1563,6 +1606,9 @@ class Mock:
             and isinstance(getattr(self.__patch.temp_original, name), property)
         ):
             return self.__get_patch_property_mock(mock, name)
+        if force_async:
+            attr_mock = umock.AsyncMock()
+            setattr(mock, name, attr_mock)
         return attr_mock
 
     @staticmethod
@@ -1579,16 +1625,27 @@ class Mock:
         *,
         create: bool,
         force_property: bool,
+        force_async: bool,
     ) -> Assert:
-        if force_property or (original is not None and isinstance(original, property)):
-            patch = umock.patch.object(
-                self.__target, name, new_callable=umock.PropertyMock, create=create
-            )
+        patch: umock._patch[Any]  # pylint: disable=unsubscriptable-object
+        if inspect.ismodule(self.__target) and not callable(original):
+            # Support mocking module attributes/variables
+            patch = umock.patch.object(self.__target, name, new=None, create=create)
+            patch.start()
+            self.__object_patches.append(patch)
+            attr_mock = umock.NonCallableMagicMock()
         else:
-            patch = umock.patch.object(self.__target, name, create=create)
-        attr_mock = patch.start()
-        self.__object_patches.append(patch)
-        assertion = Assert(self, attr_mock, name, _internal=True)
+            new_callable = None
+            if force_property or (original is not None and isinstance(original, property)):
+                new_callable = umock.PropertyMock
+            elif force_async:
+                new_callable = umock.AsyncMock
+            patch = umock.patch.object(
+                self.__target, name, new_callable=new_callable, create=create
+            )
+            attr_mock = patch.start()
+            self.__object_patches.append(patch)
+        assertion = Assert(self, attr_mock, name, patch=patch, _internal=True)
         if len(parts) > 0:
             # Support for chaining methods
             stub = Mock(_internal=True)
